Learn R Programming

glottospace (version 0.0.112)

glottolog: This is an internally stored version of glottolog data. Use glottoget("glottolog", download = TRUE) to download the latest version

Description

This is an internally stored version of glottolog data. Use glottoget("glottolog", download = TRUE) to download the latest version

Usage

glottolog

Arguments

Format

A data frame based on glottolog