powered by
Usually, you will run this function twice, once to split metadata from glottodata, and a second time to join it again.
glottosplitmergemeta(glottodata, splitted = NULL)
glottodata
if provided, the second element of the list will be joined with glottodata
A list of length 2 in case only glottodata is provided, and a merged glottodata object otherwise.
glottojoin
glottosimplify
# NOT RUN { glottodata <- glottoget("demodata", meta = TRUE) splitted <- glottosplitmergemeta(glottodata) merged <- glottosplitmergemeta(glottodata = glottodata, splitted = splitted) # }
Run the code above in your browser using DataLab